MethodChannelYandexPlugin class

An implementation of YandexPluginPlatform that uses method channels.

Inheritance

Constructors

MethodChannelYandexPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({required String yandexMapKey}) Future<Null>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited